package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.HistoryProject;
import com.ruoyi.system.service.IHistoryProjectService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 历史项目Controller
 *
 * @author ruoyi
 * @date 2024-11-18
 */
@RestController
@RequestMapping("/api/scientific/project")
public class HistoryProjectController extends BaseController
{
    @Autowired
    private IHistoryProjectService historyProjectService;

    /**
     * 查询历史项目列表
     */
    @GetMapping("/list")
    public TableDataInfo list(HistoryProject historyProject)
    {
        startPage();
        List<HistoryProject> list = historyProjectService.selectHistoryProjectList(historyProject);
        return getDataTable(list);
    }

    /**
     * 导出历史项目列表
     */
    @PreAuthorize("@ss.hasPermi('system:project:export')")
    @Log(title = "历史项目", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HistoryProject historyProject)
    {
        List<HistoryProject> list = historyProjectService.selectHistoryProjectList(historyProject);
        ExcelUtil<HistoryProject> util = new ExcelUtil<HistoryProject>(HistoryProject.class);
        util.exportExcel(response, list, "历史项目数据");
    }

    /**
     * 获取历史项目详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:project:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(historyProjectService.selectHistoryProjectById(id));
    }

    /**
     * 新增历史项目
     */
    @PreAuthorize("@ss.hasPermi('system:project:add')")
    @Log(title = "历史项目", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HistoryProject historyProject)
    {
        return toAjax(historyProjectService.insertHistoryProject(historyProject));
    }

    /**
     * 修改历史项目
     */
    @PreAuthorize("@ss.hasPermi('system:project:edit')")
    @Log(title = "历史项目", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody HistoryProject historyProject)
    {
        return toAjax(historyProjectService.updateHistoryProject(historyProject));
    }

    /**
     * 删除历史项目
     */
    @PreAuthorize("@ss.hasPermi('system:project:remove')")
    @Log(title = "历史项目", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(historyProjectService.deleteHistoryProjectByIds(ids));
    }
}