package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.OutsourcingDept;
import com.ruoyi.system.service.IOutsourcingDeptService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 外协单位Controller
 *
 * @author ruoyi
 * @date 2024-11-18
 */
@RestController
@RequestMapping("/api/scientific/Outsourcingdept")
public class OutsourcingDeptController extends BaseController
{
    @Autowired
    private IOutsourcingDeptService outsourcingDeptService;

    /**
     * 查询外协单位列表
     */
    @GetMapping("/list")
    public TableDataInfo list(OutsourcingDept outsourcingDept)
    {
        startPage();
        List<OutsourcingDept> list = outsourcingDeptService.selectOutsourcingDeptList(outsourcingDept);
        return getDataTable(list);
    }

    /**
     * 导出外协单位列表
     */
    @PreAuthorize("@ss.hasPermi('system:dept:export')")
    @Log(title = "外协单位", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, OutsourcingDept outsourcingDept)
    {
        List<OutsourcingDept> list = outsourcingDeptService.selectOutsourcingDeptList(outsourcingDept);
        ExcelUtil<OutsourcingDept> util = new ExcelUtil<OutsourcingDept>(OutsourcingDept.class);
        util.exportExcel(response, list, "外协单位数据");
    }

    /**
     * 获取外协单位详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:dept:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(outsourcingDeptService.selectOutsourcingDeptById(id));
    }

    /**
     * 新增外协单位
     */
    @PreAuthorize("@ss.hasPermi('system:dept:add')")
    @Log(title = "外协单位", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody OutsourcingDept outsourcingDept)
    {
        return toAjax(outsourcingDeptService.insertOutsourcingDept(outsourcingDept));
    }

    /**
     * 修改外协单位
     */
    @PreAuthorize("@ss.hasPermi('system:dept:edit')")
    @Log(title = "外协单位", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody OutsourcingDept outsourcingDept)
    {
        return toAjax(outsourcingDeptService.updateOutsourcingDept(outsourcingDept));
    }

    /**
     * 删除外协单位
     */
    @PreAuthorize("@ss.hasPermi('system:dept:remove')")
    @Log(title = "外协单位", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(outsourcingDeptService.deleteOutsourcingDeptByIds(ids));
    }
}