package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.OutsourcingDeptPref;
import com.ruoyi.system.service.IOutsourcingDeptPrefService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 外协单位_业绩Controller
 *
 * @author ruoyi
 * @date 2024-11-18
 */
@RestController
@RequestMapping("/api/scientific/OutsourcingDeptpref")
public class OutsourcingDeptPrefController extends BaseController
{
    @Autowired
    private IOutsourcingDeptPrefService outsourcingDeptPrefService;

    /**
     * 查询外协单位_业绩列表
     */
    @GetMapping("/list")
    public TableDataInfo list(OutsourcingDeptPref outsourcingDeptPref)
    {
        startPage();
        List<OutsourcingDeptPref> list = outsourcingDeptPrefService.selectOutsourcingDeptPrefList(outsourcingDeptPref);
        return getDataTable(list);
    }

    /**
     * 导出外协单位_业绩列表
     */
    @PreAuthorize("@ss.hasPermi('system:pref:export')")
    @Log(title = "外协单位_业绩", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, OutsourcingDeptPref outsourcingDeptPref)
    {
        List<OutsourcingDeptPref> list = outsourcingDeptPrefService.selectOutsourcingDeptPrefList(outsourcingDeptPref);
        ExcelUtil<OutsourcingDeptPref> util = new ExcelUtil<OutsourcingDeptPref>(OutsourcingDeptPref.class);
        util.exportExcel(response, list, "外协单位_业绩数据");
    }

    /**
     * 获取外协单位_业绩详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:pref:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(outsourcingDeptPrefService.selectOutsourcingDeptPrefById(id));
    }

    /**
     * 新增外协单位_业绩
     */
    @PreAuthorize("@ss.hasPermi('system:pref:add')")
    @Log(title = "外协单位_业绩", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody OutsourcingDeptPref outsourcingDeptPref)
    {
        return toAjax(outsourcingDeptPrefService.insertOutsourcingDeptPref(outsourcingDeptPref));
    }

    /**
     * 修改外协单位_业绩
     */
    @PreAuthorize("@ss.hasPermi('system:pref:edit')")
    @Log(title = "外协单位_业绩", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody OutsourcingDeptPref outsourcingDeptPref)
    {
        return toAjax(outsourcingDeptPrefService.updateOutsourcingDeptPref(outsourcingDeptPref));
    }

    /**
     * 删除外协单位_业绩
     */
    @PreAuthorize("@ss.hasPermi('system:pref:remove')")
    @Log(title = "外协单位_业绩", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(outsourcingDeptPrefService.deleteOutsourcingDeptPrefByIds(ids));
    }
}