package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.OutsourcingWxxsps;
import com.ruoyi.system.service.IOutsourcingWxxspsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 外协选商评审Controller
 *
 * @author ruoyi
 * @date 2025-02-26
 */
@RestController
@RequestMapping("/system/wxxsps/Outsourcing")
public class OutsourcingWxxspsController extends BaseController
{
    @Autowired
    private IOutsourcingWxxspsService outsourcingWxxspsService;

    /**
     * 查询外协选商评审列表
     */

    @GetMapping("/list")
    public TableDataInfo list(OutsourcingWxxsps outsourcingWxxsps)
    {
        startPage();
        List<OutsourcingWxxsps> list = outsourcingWxxspsService.selectOutsourcingWxxspsList(outsourcingWxxsps);
        return getDataTable(list);
    }

    /**
     * 导出外协选商评审列表
     */

    @Log(title = "外协选商评审", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, OutsourcingWxxsps outsourcingWxxsps)
    {
        List<OutsourcingWxxsps> list = outsourcingWxxspsService.selectOutsourcingWxxspsList(outsourcingWxxsps);
        ExcelUtil<OutsourcingWxxsps> util = new ExcelUtil<OutsourcingWxxsps>(OutsourcingWxxsps.class);
        util.exportExcel(response, list, "外协选商评审数据");
    }

    /**
     * 获取外协选商评审详细信息
     */

    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(outsourcingWxxspsService.selectOutsourcingWxxspsById(id));
    }

    /**
     * 新增外协选商评审
     */

    @Log(title = "外协选商评审", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody OutsourcingWxxsps outsourcingWxxsps)
    {
        return toAjax(outsourcingWxxspsService.insertOutsourcingWxxsps(outsourcingWxxsps));
    }

    /**
     * 修改外协选商评审
     */

    @Log(title = "外协选商评审", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody OutsourcingWxxsps outsourcingWxxsps)
    {
        return toAjax(outsourcingWxxspsService.updateOutsourcingWxxsps(outsourcingWxxsps));
    }

    /**
     * 删除外协选商评审
     */

    @Log(title = "外协选商评审", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(outsourcingWxxspsService.deleteOutsourcingWxxspsByIds(ids));
    }
}
