package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ProgroupProjectFundingMx;
import com.ruoyi.system.service.IProgroupProjectFundingMxService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 项目管理_经费明细Controller
 *
 * @author ruoyi
 * @date 2024-11-12
 */
@RestController
@RequestMapping("/api/scientific/mx")
public class ProgroupProjectFundingMxController extends BaseController
{
    @Autowired
    private IProgroupProjectFundingMxService progroupProjectFundingMxService;

    /**
     * 查询项目管理_经费明细列表
     */
    @GetMapping("/list")
    public TableDataInfo list(ProgroupProjectFundingMx progroupProjectFundingMx)
    {
        startPage();
        List<ProgroupProjectFundingMx> list = progroupProjectFundingMxService.selectProgroupProjectFundingMxList(progroupProjectFundingMx);
        return getDataTable(list);
    }

    /**
     * 导出项目管理_经费明细列表
     */
    @PreAuthorize("@ss.hasPermi('system:mx:export')")
    @Log(title = "项目管理_经费明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProgroupProjectFundingMx progroupProjectFundingMx)
    {
        List<ProgroupProjectFundingMx> list = progroupProjectFundingMxService.selectProgroupProjectFundingMxList(progroupProjectFundingMx);
        ExcelUtil<ProgroupProjectFundingMx> util = new ExcelUtil<ProgroupProjectFundingMx>(ProgroupProjectFundingMx.class);
        util.exportExcel(response, list, "项目管理_经费明细数据");
    }

    /**
     * 获取项目管理_经费明细详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:mx:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(progroupProjectFundingMxService.selectProgroupProjectFundingMxById(id));
    }

    /**
     * 新增项目管理_经费明细
     */
    @PreAuthorize("@ss.hasPermi('system:mx:add')")
    @Log(title = "项目管理_经费明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ProgroupProjectFundingMx progroupProjectFundingMx)
    {
        return toAjax(progroupProjectFundingMxService.insertProgroupProjectFundingMx(progroupProjectFundingMx));
    }

    /**
     * 修改项目管理_经费明细
     */
    @PreAuthorize("@ss.hasPermi('system:mx:edit')")
    @Log(title = "项目管理_经费明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ProgroupProjectFundingMx progroupProjectFundingMx)
    {
        return toAjax(progroupProjectFundingMxService.updateProgroupProjectFundingMx(progroupProjectFundingMx));
    }

    /**
     * 删除项目管理_经费明细
     */
    @PreAuthorize("@ss.hasPermi('system:mx:remove')")
    @Log(title = "项目管理_经费明细", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(progroupProjectFundingMxService.deleteProgroupProjectFundingMxByIds(ids));
    }
}