package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ProgroupProjectProgress;
import com.ruoyi.system.service.IProgroupProjectProgressService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 项目群 项目进展管理Controller
 *
 * @author ruoyi
 * @date 2024-11-18
 */
@RestController
@RequestMapping("/api/scientific/ProgroupProjectprogress")
public class ProgroupProjectProgressController extends BaseController
{
    @Autowired
    private IProgroupProjectProgressService progroupProjectProgressService;

    /**
     * 查询项目群 项目进展管理列表
     */
    @GetMapping("/list")
    public TableDataInfo list(ProgroupProjectProgress progroupProjectProgress)
    {
        startPage();
        List<ProgroupProjectProgress> list = progroupProjectProgressService.selectProgroupProjectProgressList(progroupProjectProgress);
        return getDataTable(list);
    }

    /**
     * 导出项目群 项目进展管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:progress:export')")
    @Log(title = "项目群 项目进展管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProgroupProjectProgress progroupProjectProgress)
    {
        List<ProgroupProjectProgress> list = progroupProjectProgressService.selectProgroupProjectProgressList(progroupProjectProgress);
        ExcelUtil<ProgroupProjectProgress> util = new ExcelUtil<ProgroupProjectProgress>(ProgroupProjectProgress.class);
        util.exportExcel(response, list, "项目群 项目进展管理数据");
    }

    /**
     * 获取项目群 项目进展管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:progress:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(progroupProjectProgressService.selectProgroupProjectProgressById(id));
    }

    /**
     * 新增项目群 项目进展管理
     */
    @PreAuthorize("@ss.hasPermi('system:progress:add')")
    @Log(title = "项目群 项目进展管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ProgroupProjectProgress progroupProjectProgress)
    {
        return toAjax(progroupProjectProgressService.insertProgroupProjectProgress(progroupProjectProgress));
    }

    /**
     * 修改项目群 项目进展管理
     */
    @PreAuthorize("@ss.hasPermi('system:progress:edit')")
    @Log(title = "项目群 项目进展管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ProgroupProjectProgress progroupProjectProgress)
    {
        return toAjax(progroupProjectProgressService.updateProgroupProjectProgress(progroupProjectProgress));
    }

    /**
     * 删除项目群 项目进展管理
     */
    @PreAuthorize("@ss.hasPermi('system:progress:remove')")
    @Log(title = "项目群 项目进展管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(progroupProjectProgressService.deleteProgroupProjectProgressByIds(ids));
    }
}
