package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ProjectDictCategory;
import com.ruoyi.system.service.IProjectDictCategoryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 项目类别字典Controller
 *
 * @author ruoyi
 * @date 2025-01-16
 */
@RestController
@RequestMapping("/api/scientific/category")
public class ProjectDictCategoryController extends BaseController
{
    @Autowired
    private IProjectDictCategoryService projectDictCategoryService;

    /**
     * 查询项目类别字典列表
     */

    @GetMapping("/list")
    public TableDataInfo list(ProjectDictCategory projectDictCategory)
    {
        startPage();
        List<ProjectDictCategory> list = projectDictCategoryService.selectProjectDictCategoryList(projectDictCategory);
        return getDataTable(list);
    }

    /**
     * 导出项目类别字典列表
     */

    @Log(title = "项目类别字典", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProjectDictCategory projectDictCategory)
    {
        List<ProjectDictCategory> list = projectDictCategoryService.selectProjectDictCategoryList(projectDictCategory);
        ExcelUtil<ProjectDictCategory> util = new ExcelUtil<ProjectDictCategory>(ProjectDictCategory.class);
        util.exportExcel(response, list, "项目类别字典数据");
    }

    /**
     * 获取项目类别字典详细信息
     */

    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(projectDictCategoryService.selectProjectDictCategoryById(id));
    }

    /**
     * 新增项目类别字典
     */

    @Log(title = "项目类别字典", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ProjectDictCategory projectDictCategory)
    {
        return toAjax(projectDictCategoryService.insertProjectDictCategory(projectDictCategory));
    }

    /**
     * 修改项目类别字典
     */

    @Log(title = "项目类别字典", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ProjectDictCategory projectDictCategory)
    {
        return toAjax(projectDictCategoryService.updateProjectDictCategory(projectDictCategory));
    }

    /**
     * 删除项目类别字典
     */

    @Log(title = "项目类别字典", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(projectDictCategoryService.deleteProjectDictCategoryByIds(ids));
    }
}
