package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ProjectDictProfession;
import com.ruoyi.system.service.IProjectDictProfessionService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 项目专业字典Controller
 *
 * @author ruoyi
 * @date 2025-01-16
 */
@RestController
@RequestMapping("/api/scientific/profession")
public class ProjectDictProfessionController extends BaseController
{
    @Autowired
    private IProjectDictProfessionService projectDictProfessionService;

    /**
     * 查询项目专业字典列表
     */

    @GetMapping("/list")
    public TableDataInfo list(ProjectDictProfession projectDictProfession)
    {
        startPage();
        List<ProjectDictProfession> list = projectDictProfessionService.selectProjectDictProfessionList(projectDictProfession);
        return getDataTable(list);
    }

    /**
     * 导出项目专业字典列表
     */

    @Log(title = "项目专业字典", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProjectDictProfession projectDictProfession)
    {
        List<ProjectDictProfession> list = projectDictProfessionService.selectProjectDictProfessionList(projectDictProfession);
        ExcelUtil<ProjectDictProfession> util = new ExcelUtil<ProjectDictProfession>(ProjectDictProfession.class);
        util.exportExcel(response, list, "项目专业字典数据");
    }

    /**
     * 获取项目专业字典详细信息
     */

    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(projectDictProfessionService.selectProjectDictProfessionById(id));
    }

    /**
     * 新增项目专业字典
     */

    @Log(title = "项目专业字典", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ProjectDictProfession projectDictProfession)
    {
        return toAjax(projectDictProfessionService.insertProjectDictProfession(projectDictProfession));
    }

    /**
     * 修改项目专业字典
     */

    @Log(title = "项目专业字典", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ProjectDictProfession projectDictProfession)
    {
        return toAjax(projectDictProfessionService.updateProjectDictProfession(projectDictProfession));
    }

    /**
     * 删除项目专业字典
     */

    @Log(title = "项目专业字典", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(projectDictProfessionService.deleteProjectDictProfessionByIds(ids));
    }
}
