package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ScientificDiscGuide;
import com.ruoyi.system.service.IScientificDiscGuideService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 指南字典Controller
 *
 * @author ruoyi
 * @date 2025-01-16
 */
@RestController
@RequestMapping("/api/scientific/guide")
public class ScientificDiscGuideController extends BaseController
{
    @Autowired
    private IScientificDiscGuideService scientificDiscGuideService;

    /**
     * 查询指南字典列表
     */

    @GetMapping("/list")
    public TableDataInfo list(ScientificDiscGuide scientificDiscGuide)
    {
        startPage();
        List<ScientificDiscGuide> list = scientificDiscGuideService.selectScientificDiscGuideList(scientificDiscGuide);
        return getDataTable(list);
    }

    /**
     * 导出指南字典列表
     */

    @Log(title = "指南字典", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ScientificDiscGuide scientificDiscGuide)
    {
        List<ScientificDiscGuide> list = scientificDiscGuideService.selectScientificDiscGuideList(scientificDiscGuide);
        ExcelUtil<ScientificDiscGuide> util = new ExcelUtil<ScientificDiscGuide>(ScientificDiscGuide.class);
        util.exportExcel(response, list, "指南字典数据");
    }

    /**
     * 获取指南字典详细信息
     */

    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(scientificDiscGuideService.selectScientificDiscGuideById(id));
    }

    /**
     * 新增指南字典
     */

    @Log(title = "指南字典", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ScientificDiscGuide scientificDiscGuide)
    {
        return toAjax(scientificDiscGuideService.insertScientificDiscGuide(scientificDiscGuide));
    }

    /**
     * 修改指南字典
     */

    @Log(title = "指南字典", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ScientificDiscGuide scientificDiscGuide)
    {
        return toAjax(scientificDiscGuideService.updateScientificDiscGuide(scientificDiscGuide));
    }

    /**
     * 删除指南字典
     */

    @Log(title = "指南字典", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(scientificDiscGuideService.deleteScientificDiscGuideByIds(ids));
    }
}
