package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ScientificGuide;
import com.ruoyi.system.service.IScientificGuideService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 科研指南;指南和项目征集放在一起Controller
 *
 * @author ruoyi
 * @date 2025-01-16
 */
@RestController
@RequestMapping("/api/scientific/ss/guide")
public class ScientificGuideController extends BaseController
{
    @Autowired
    private IScientificGuideService scientificGuideService;

    /**
     * 查询科研指南;指南和项目征集放在一起列表
     */

    @GetMapping("/list")
    public TableDataInfo list(ScientificGuide scientificGuide)
    {
        startPage();
        List<ScientificGuide> list = scientificGuideService.selectScientificGuideList(scientificGuide);
        return getDataTable(list);
    }

    /**
     * 导出科研指南;指南和项目征集放在一起列表
     */

    @Log(title = "科研指南;指南和项目征集放在一起", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ScientificGuide scientificGuide)
    {
        List<ScientificGuide> list = scientificGuideService.selectScientificGuideList(scientificGuide);
        ExcelUtil<ScientificGuide> util = new ExcelUtil<ScientificGuide>(ScientificGuide.class);
        util.exportExcel(response, list, "科研指南;指南和项目征集放在一起数据");
    }

    /**
     * 获取科研指南;指南和项目征集放在一起详细信息
     */

    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(scientificGuideService.selectScientificGuideById(id));
    }

    /**
     * 新增科研指南;指南和项目征集放在一起
     */

    @Log(title = "科研指南;指南和项目征集放在一起", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ScientificGuide scientificGuide)
    {
        return toAjax(scientificGuideService.insertScientificGuide(scientificGuide));
    }

    /**
     * 修改科研指南;指南和项目征集放在一起
     */

    @Log(title = "科研指南;指南和项目征集放在一起", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ScientificGuide scientificGuide)
    {
        return toAjax(scientificGuideService.updateScientificGuide(scientificGuide));
    }

    /**
     * 删除科研指南;指南和项目征集放在一起
     */

    @Log(title = "科研指南;指南和项目征集放在一起", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(scientificGuideService.deleteScientificGuideByIds(ids));
    }
}
